### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [v0.1.6](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.5...v0.1.6)

> 18 May 2021

- Adding v0.1.5 Changelog updates [`266362f`](https://github.com/keyko-io/defi-crawler-py/commit/266362f769a7bb64b47d44e939ba97feb434b42a)
- manifest [`9b74929`](https://github.com/keyko-io/defi-crawler-py/commit/9b749296d3f94fcea86e1d4199e3aa9f6d54b00b)

#### [v0.1.5](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.4...v0.1.5)

> 18 May 2021

- Adding v0.1.4 Changelog updates [`4fd4081`](https://github.com/keyko-io/defi-crawler-py/commit/4fd40811237eca74fe50572a5051a26ba142bcc8)
- manifest [`8cb2942`](https://github.com/keyko-io/defi-crawler-py/commit/8cb29425fc22fafa44a6f7e6ebceddba5e5e90af)

#### [v0.1.4](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.2...v0.1.4)

> 18 May 2021

#### [v0.1.2](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.1...v0.1.2)

> 18 May 2021

- Adding v0.1.1 Changelog updates [`fe97ab2`](https://github.com/keyko-io/defi-crawler-py/commit/fe97ab232822014d3840124715452d2829096683)
- Update setup.py [`d1fa65d`](https://github.com/keyko-io/defi-crawler-py/commit/d1fa65d5606e634bd8ebf431955b39a3ff5451b1)

#### [v0.1.1](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.0...v0.1.1)

> 18 May 2021

- Adding v0.1.0  Changelog updates [`360b7f0`](https://github.com/keyko-io/defi-crawler-py/commit/360b7f0195eab717a2d7854d7ab49b025e1bf844)

#### v0.1.0

> 18 May 2021

- setup config and examples [`#35`](https://github.com/keyko-io/defi-crawler-py/pull/35)
- dexes [`#34`](https://github.com/keyko-io/defi-crawler-py/pull/34)
- pool filter [`#33`](https://github.com/keyko-io/defi-crawler-py/pull/33)
- feat: supported entities [`#32`](https://github.com/keyko-io/defi-crawler-py/pull/32)
- update docs after refactor [`#31`](https://github.com/keyko-io/defi-crawler-py/pull/31)
- refactor split protocol types [`#30`](https://github.com/keyko-io/defi-crawler-py/pull/30)
- Feat/exchange prices [`#29`](https://github.com/keyko-io/defi-crawler-py/pull/29)
- Docs [`#28`](https://github.com/keyko-io/defi-crawler-py/pull/28)
- comments [`#25`](https://github.com/keyko-io/defi-crawler-py/pull/25)
- Integration tests [`#24`](https://github.com/keyko-io/defi-crawler-py/pull/24)
- Unit testing [`#23`](https://github.com/keyko-io/defi-crawler-py/pull/23)
- refactor [`#22`](https://github.com/keyko-io/defi-crawler-py/pull/22)
- oracles [`#21`](https://github.com/keyko-io/defi-crawler-py/pull/21)
- feat: lending protocols [`#20`](https://github.com/keyko-io/defi-crawler-py/pull/20)
- refactor: extra query fields [`#19`](https://github.com/keyko-io/defi-crawler-py/pull/19)
- units functions [`#17`](https://github.com/keyko-io/defi-crawler-py/pull/17)
- several blockchains [`#16`](https://github.com/keyko-io/defi-crawler-py/pull/16)
- users data [`#15`](https://github.com/keyko-io/defi-crawler-py/pull/15)
- dynamic mappings, transforms &  json configs [`#14`](https://github.com/keyko-io/defi-crawler-py/pull/14)
- Feature/dynamic mappings [`#12`](https://github.com/keyko-io/defi-crawler-py/pull/12)
- amm docs [`#10`](https://github.com/keyko-io/defi-crawler-py/pull/10)
- prices entities [`#8`](https://github.com/keyko-io/defi-crawler-py/pull/8)
- Feat/lending docs [`#7`](https://github.com/keyko-io/defi-crawler-py/pull/7)
- lending mappers [`d7733a1`](https://github.com/keyko-io/defi-crawler-py/commit/d7733a102e51c3c72c8adc9dc78d17e339fe2b77)
- amm mappers and dinamic querys [`0b6fee6`](https://github.com/keyko-io/defi-crawler-py/commit/0b6fee61f56dbeca08fa01a1ee831b3fccc47fe7)
- integration tests [`9065f3c`](https://github.com/keyko-io/defi-crawler-py/commit/9065f3c621e0108dca94c10a889420fcb2be1de1)
